from django.forms.fields import ImageField
from .widgets import SubjectImageInput
from .config import get_config


class SubjectImageFormField(ImageField):
    widget = SubjectImageInput

    def __init__(self, subject_location_field=None, *args, **kwargs):
        self.subject_location_field = subject_location_field
        return super(SubjectImageFormField, self).__init__(*args, **kwargs)

    def widget_attrs(self, widget):
        attrs = super(SubjectImageFormField, self).widget_attrs(widget)
        attrs['subject_location_field'] = self.subject_location_field
        attrs['preview_width'] = get_config('PREVIEW_WIDTH')
        return attrs



# -*- coding: utf-8 -*-
from django.conf import settings
from django.core.exceptions import ImproperlyConfigured

default_config = {
    'PREVIEW_WIDTH': 300
}


def get_config(key):
    user_settings = getattr(settings, 'SUBJECT_IMAGEFIELD', None)

    if user_settings is None:
        value = default_config.get(key, None)
    else:
        value = user_settings.get(key, default_config.get(key, None))

    if not isinstance(value, int):
        raise ImproperlyConfigured('PREVIEW_WIDTH setting must be an integer')

    return value
